clc; 
clear;
close all

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Author: Erik Andre Klepp Vik
%% Mail: eavik@stud.ntnu.no
%% Date: 18.12.2020
%% Notes: Built on tube and valve model supplied by Cristina F. Zotica
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Description:
% This is the main file for showing disturbance rejection for different  
% advanced controller structures. 
% 
% NOTE: To run this file, P0Variables.m must be run first!
% 
% Tunings are obtained through open loop responses.
% This document only implements the final tunings applied to different
% controller structures and the corresponding responses for a positive
% and negative step in P1. Other disturbances and steps can also be 
% implemented.
% 
%  - For plotting file, see P0Plot.m
% 
%  - For ODE file, see P0PressureFlowODE.m
% 
%  - For Simulink file, see P0PressureFlowODE.m
% 
%  - For variable file, see P0Variables.m
% 
% NOTE: For this file to run, P0Variables.m should be run first!
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% First Simulation - Open loop responses

% Load file to reset variables for new simulation

load('P0Variables')

% Select relevant feedback loops using gains in Simulink:
% (Does not really matter for open loop simulation)
case1 = 1; 
z1feed = Pnom;
z2feed = q2nom;
z3feed = q3nom;
z4feed = q4nom;

% Simulate step in z1, all loops open

z1st   = 0;
z2st   = 0;
z3st   = 0;
z4st   = 0;
z1dist = z1nom*0.1;
z2dist = 0;
z3dist = 0;
z4dist = 0;
P1dist = 0;
P2dist = 0;
P3dist = 0;
P4dist = 0;

sim('P0PressureFlowODESim')

qnomplot = t.^(0)*2.2;
q2plot   = q2stepplot;
q3plot   = q3stepplot;
q4plot   = q4stepplot;

save(fullfile(savdir,'P9901CL'));

% Plot pressures and and flows

plotname = 'Open loop response, +10% Step in z_1';
number   = 1;
save('P0Workspace');
P0Plot();

% Simulate step in z2, all loops open

z1st   = 0;
z2st   = 0;
z3st   = 0;
z4st   = 0;
z1dist = 0;
z2dist = z2nom*0.1;
z3dist = 0;
z4dist = 0;
P1dist = 0;
P2dist = 0;
P3dist = 0;
P4dist = 0;

sim('P0PressureFlowODESim')

qnomplot = t.^(0)*2.2;
q2plot   = q2stepplot;
q3plot   = q3stepplot;
q4plot   = q4stepplot;

save(fullfile(savdir,'P9902CL'));

% Plot pressures and and flows

plotname = 'Open loop response, +10% Step in z_2';
number   = 2;
save('P0Workspace');
P0Plot();

%% Second Simulation - Default Control using Supplier and Consumers
% PI-controller for z1, I-controllers for z2,z3,z4
% Load file to reset variables for new simulation

load('P0Variables')

% Select relevant feedback loops using gains in Simulink:
case1 = 1;
z1feed = Pnom;
z2feed = q2nom;
z3feed = q3nom;
z4feed = q4nom;

% Tunings all controllers tuned. 
tauC = V/((qnom*R*T)/Pnom);

k_p     = 0.51/0.05;      %10
tau_p   = 10000;           %57
theta_p = 0;            %0
tau_p_c = tauC;        %25    %1
tau_p_I = min(tau_p,4*tau_p_c);    %4

controller_P_P  = 1/k_p * tau_p/(theta_p+tau_p_c);
controller_P_I  = controller_P_P/tau_p_I;

% Outlet Controllers
k2     = 0.05/0.05;
theta2 = 0;
k3     = 0.075/0.05;
theta3 = 0;
k4     = 0.075/0.05;
theta4 = 0;
controller_q2_I = 1/k2 * 1/(theta2+tau_p_c); 
controller_q3_I = 1/k3 * 1/(theta3+tau_p_c); 
controller_q4_I = 1/k4 * 1/(theta4+tau_p_c); 

% Anti Windup Parameters
Kb   = controller_P_I;
Kbq2 = controller_q2_I;
Kbq3 = controller_q3_I;
Kbq4 = controller_q4_I;

% Simulate SP change for P, to see PI controller response
z1st   = 0;                                    % Pressure SP input
z2st   = 0;                                    % q2 SP input
z3st   = 0;                                    % q3 SP input
z4st   = 0;                                    % q4 SP input
z1dist = 0;                                    % Valve one input
z2dist = 0;                                    % Valve one input
z3dist = 0;                                    % Valve one input
z4dist = 0;                                    % Valve one input
P1dist = P1;                                   % Disturbance P1 input
P2dist = 0;                                    % Disturbance P2 input
P3dist = 0;                                    % Disturbance P3 input
P4dist = 0;                                    % Disturbance P4 input

sim('P0PressureFlowODESim')                    % Run Simulink file

qnomplot = t.^(0)*2.2;                         % Prepare plotting variables
q2plot   = q2stepplot;                         % Prepare plotting variables
q3plot   = q3stepplot;                         % Prepare plotting variables
q4plot   = q4stepplot;                         % Prepare plotting variables

save(fullfile(savdir,'P9903CL'));              % Save variables for later

% Plot pressures and and flows
%pressures
plotname = 'Default Supplier and Consumer control, +100% Dist on P1';
number   = 3;
save('P0Workspace');
P0Plot();

% Simulate SP change for P, to see PI controller response
z1st   = 0;                                    % Pressure SP input
z2st   = 0;                                    % q2 SP input
z3st   = 0;                                    % q3 SP input
z4st   = 0;                                    % q4 SP input
z1dist = 0;                                    % Valve one input
z2dist = 0;                                    % Valve one input
z3dist = 0;                                    % Valve one input
z4dist = 0;                                    % Valve one input
P1dist = -P1*0.3;                              % Disturbance P1 input
P2dist = 0;                                    % Disturbance P2 input
P3dist = 0;                                    % Disturbance P3 input
P4dist = 0;                                    % Disturbance P4 input

sim('P0PressureFlowODESim')                    % Run Simulink file

qnomplot = t.^(0)*2.2;                         % Prepare plotting variables
q2plot   = q2stepplot;                         % Prepare plotting variables
q3plot   = q3stepplot;                         % Prepare plotting variables
q4plot   = q4stepplot;                         % Prepare plotting variables

save(fullfile(savdir,'P9904CL'));              % Save variables for later

% Plot pressures and and flows
% pressures
plotname = 'Default Supplier and Consumer control, -30% Dist on P1';
number   = 4;
save('P0Workspace');
P0Plot();

%% Third Simulation - Parallel Control
% PI controller for z2, P-controllers for z3,z4

% Load file to reset variables for new simulation
load('P0Variables')

% Select relevant feedback loops and feeds using gains in Simulink:
case2 = 1;
z1feed = Pnom; %Only used for plotting, not used becasue controller not on.
z2feed = Pnom;
z3feed = Pnom;
z4feed = Pnom;

% Tune PI controller for P control
tauC = V/((qnom*R*T)/Pnom);

k_p2     = -0.058/0.05;      %10
tau_p2   = 5000;           %57
theta_p2 = 0;            %0
tau_p_c2 = tauC;        %25    %1
tau_p_I2 = min(tau_p2,4*tau_p_c2);    %4

controller_q2_P  = 1/k_p2 * tau_p2/(theta_p2+tau_p_c2);
controller_q2_I  = controller_q2_P/tau_p_I2;

k_p3     = -0.201/0.05;      
tau_p3   = 12500;           
theta_p3 = 0;          
tau_p_c3 = tauC;        
tau_p_I3 = min(tau_p3,4*tau_p_c3);   

controller_q3_P  = 1/k_p3 * tau_p3/(theta_p3+tau_p_c3);

k_p4     = -0.122/0.05;      
tau_p4   = 7500;           
theta_p4 = 0;           
tau_p_c4 = tauC;        
tau_p_I4 = min(tau_p4,4*tau_p_c4);   

controller_q4_P = 1/k_p4 * tau_p4/(theta_p4+tau_p_c4);

% Anti Windup Parameters
Kbq2   = controller_q2_I;
% Simulate SP change for P, to see PI controller response
z1st   = 0;                                    % Pressure SP input
z2st   = 0;                                    % q2 SP input
z3st   = 0;                                    % q3 SP input
z4st   = 0;                                    % q4 SP input
z1dist = 0;                                    % Valve one input
z2dist = 0;                                    % Valve one input
z3dist = 0;                                    % Valve one input
z4dist = 0;                                    % Valve one input
P1dist = P1;                                   % Disturbance P1 input
P2dist = 0;                                    % Disturbance P2 input
P3dist = 0;                                    % Disturbance P3 input
P4dist = 0;                                    % Disturbance P4 input

sim('P0PressureFlowODESim')                    % Run Simulink file

pstepplot = q2stepplot;                        % Preparing plotting
qnomplot = t.^(0)*2.2;                         % Preparing plotting
q2plot   = t.^(0)*0.5;                         % Preparing plotting
q3plot   = t.^(0)*0.75;                        % Preparing plotting
q4plot   = t.^(0)*0.75;                        % Preparing plotting

save(fullfile(savdir,'P9905CL'));              % Save variables for later

% Plot pressures and and flows
%pressures
plotname = 'Parallel Control, +100% Dist on P1';
number   = 5;
save('P0Workspace');
P0Plot();

% Simulate SP change for P, to see PI controller response
z1st   = 0;                                    % Pressure SP input
z2st   = 0;                                    % q2 SP input
z3st   = 0;                                    % q3 SP input
z4st   = 0;                                    % q4 SP input
z1dist = 0;                                    % Valve one input
z2dist = 0;                                    % Valve one input
z3dist = 0;                                    % Valve one input
z4dist = 0;                                    % Valve one input
P1dist = -P1*0.3;                              % Disturbance P1 input
P2dist = 0;                                    % Disturbance P2 input
P3dist = 0;                                    % Disturbance P3 input
P4dist = 0;                                    % Disturbance P4 input

sim('P0PressureFlowODESim')                    % Run Simulink file

pstepplot = q2stepplot;                        % Preparing plotting
qnomplot = t.^(0)*2.2;                         % Preparing plotting
q2plot   = t.^(0)*0.5;                         % Preparing plotting
q3plot   = t.^(0)*0.75;                        % Preparing plotting
q4plot   = t.^(0)*0.75;                        % Preparing plotting

save(fullfile(savdir,'P9906CL'));              % Save variables for later

% Plot pressures and and flows
%pressures
plotname = 'Parallel Control, -30% Dist on P1';
number   = 6;
save('P0Workspace');
P0Plot();

%% Fourth Simulation - Different Setpoint Control
% PI-controllers for z2,z3,z4 

% Load file to reset variables for new simulation
load('P0Variables')

% Select relevant feedback loops and feeds using gains in Simulink:
case2 = 1;
z1feed = Pnom; %Only used for plotting, in reality 0.
z2feed = Pnom-1; %This is where we change setpoints. 
z3feed = Pnom-0.5; %This is where we change setpoints.
z4feed = Pnom; %This is where we change setpoints.

% All controllers tuned
tauC = V/((qnom*R*T)/Pnom);

k_p2     = -0.135/0.05;      
tau_p2   = 12000;        
theta_p2 = 0;         
tau_p_c2 = tauC;      
tau_p_I2 = min(tau_p2,4*tau_p_c2);   

controller_q2_P  = 1/k_p2 * tau_p2/(theta_p2+tau_p_c2);
controller_q2_I  = controller_q2_P/tau_p_I2;

k_p3     = -0.094/0.05;    
tau_p3   = 4000;         
theta_p3 = 0;        
tau_p_c3 = tauC;        
tau_p_I3 = min(tau_p3,4*tau_p_c3);    

controller_q3_P  = 1/k_p3 * tau_p3/(theta_p3+tau_p_c3);
controller_q3_I  = controller_q3_P/tau_p_I3;

k_p4     = -0.066/0.05;     
tau_p4   = 3000;          
theta_p4 = 0;            
tau_p_c4 = tauC;       
tau_p_I4 = min(tau_p4,4*tau_p_c4);   

controller_q4_P  = 1/k_p4 * tau_p4/(theta_p4+tau_p_c4);
controller_q4_I  = controller_q4_P/tau_p_I4;


%Anti Windup Parameters
Kbq2   = controller_q2_I;
Kbq3   = controller_q3_I;
Kbq4   = controller_q4_I;

% Simulate SP change for P, to see PI controller response
z1st   = 0;                                    % Pressure SP input
z2st   = 0;                                    % q2 SP input
z3st   = 0;                                    % q3 SP input
z4st   = 0;                                    % q4 SP input
z1dist = 0;                                    % Valve one input
z2dist = 0;                                    % Valve one input
z3dist = 0;                                    % Valve one input
z4dist = 0;                                    % Valve one input
P1dist = P1;                                   % Disturbance P1 input
P2dist = 0;                                    % Disturbance P2 input
P3dist = 0;                                    % Disturbance P3 input
P4dist = 0;                                    % Disturbance P4 input

sim('P0PressureFlowODESim')                    % Run Simulink file

pstepplot = q2stepplot;                        % Preparing plotting
qnomplot = t.^(0)*2.2;                         % Preparing plotting
q2plot   = t.^(0)*0.5;                         % Preparing plotting
q3plot   = t.^(0)*0.75;                        % Preparing plotting
q4plot   = t.^(0)*0.75;                        % Preparing plotting

save(fullfile(savdir,'P9907CL'));              % Save variables for later

% Plot pressures and and flows
%pressures
plotname = 'Different Setpoints, +100% Dist on P1';
number   = 7;
save('P0Workspace');
P0Plot();

% Simulate SP change for P, to see PI controller response
z1st   = 0;                                    % Pressure SP input
z2st   = 0;                                    % q2 SP input
z3st   = 0;                                    % q3 SP input
z4st   = 0;                                    % q4 SP input
z1dist = 0;                                    % Valve one input
z2dist = 0;                                    % Valve one input
z3dist = 0;                                    % Valve one input
z4dist = 0;                                    % Valve one input
P1dist = -P1*0.3;                              % Disturbance P1 input
P2dist = 0;                                    % Disturbance P2 input
P3dist = 0;                                    % Disturbance P3 input
P4dist = 0;                                    % Disturbance P4 input

sim('P0PressureFlowODESim')                    % Run Simulink file

pstepplot = q2stepplot;                        % Preparing plotting
qnomplot = t.^(0)*2.2;                         % Preparing plotting
q2plot   = t.^(0)*0.5;                         % Preparing plotting
q3plot   = t.^(0)*0.75;                        % Preparing plotting
q4plot   = t.^(0)*0.75;                        % Preparing plotting

save(fullfile(savdir,'P9908CL'));              % Save variables for later

% Plot pressures and and flows
%pressures
plotname = 'Different Setpoints, -30% Dist on P1';
number   = 8;
save('P0Workspace');
P0Plot();

%% Fifth Simulation - Droop Control
% I-controllers for z2,z3,z4 P-controllers for q3sp and q4sp
% Load file to reset variables for new simulation

load('P0Variables')

% Select relevant feedback loops using gains in Simulink:
droop1 = 1;
droop2 = 1;
case1 = 1;
z1feed = Pnom;
z2feed = q2nom;
z3feed = q3nom;
z4feed = q4nom;

%% Tunings all controllers tuned. 
tauC = V/((qnom*R*T)/Pnom);

k_p     = 0.51/0.05;     
tau_p   = 10000;         
theta_p = 0;            
tau_p_c = tauC;       
tau_p_I = min(tau_p,4*tau_p_c);    

controller_P_P  = 1/k_p * tau_p/(theta_p+tau_p_c);
controller_P_I  = controller_P_P/tau_p_I;

%Outlet Controllers
k2     = 0.05/0.05;
theta2 = 0;
k3     = 0.0825/0.05;
theta3 = 0;
k4     = 0.08787/0.05;
theta4 = 0;
controller_q2_I = 1/k2 * 1/(theta2+tau_p_c); 
controller_q3_I = 1/k3 * 1/(theta3+tau_p_c); 
controller_q4_I = 1/k4 * 1/(theta4+tau_p_c); 

%Anti Windup Parameters
Kb   = controller_P_I;
Kbq2 = controller_q2_I;
Kbq3 = controller_q3_I;
Kbq4 = controller_q4_I;

k_p4     = -0.57/0.05;     
tau_p4   = 17000;         
theta_p4 = 0;            
tau_p_c4 = tauC;       
tau_p_I4 = min(tau_p4,4*tau_p_c4);

k_p3     = -0.86/0.05;     
tau_p3   = 17000;         
theta_p3 = 0;            
tau_p_c3 = tauC;       
tau_p_I3 = min(tau_p3,4*tau_p_c3);

controller_q3_Pdroop = 1/k_p3 * tau_p3/(theta_p+tau_p_c3);
controller_q4_Pdroop = 1/k_p4 * tau_p4/(theta_p+tau_p_c4);

% Simulate SP change for P, to see PI controller response
z1st   = 0;                                    % Pressure SP input
z2st   = 0;                                    % q2 SP input
z3st   = 0;                                    % q3 SP input
z4st   = 0;                                    % q4 SP input
z1dist = 0;                                    % Valve one input
z2dist = 0;                                    % Valve one input
z3dist = 0;                                    % Valve one input
z4dist = 0;                                    % Valve one input
P1dist = P1;                                   % Disturbance P1 input
P2dist = 0;                                    % Disturbance P2 input
P3dist = 0;                                    % Disturbance P3 input
P4dist = 0;                                    % Disturbance P4 input

sim('P0PressureFlowODESim')                    % Run Simulink file

qnomplot = t.^(0)*2.2;                         % Prepare plotting variables
q2plot   = q2stepplot;                         % Prepare plotting variables
q3plot   = q3stepplot;                         % Prepare plotting variables
q4plot   = q4stepplot;                         % Prepare plotting variables

save(fullfile(savdir,'P9909CL'));              % Save variables for later

% Plot pressures and and flows
%pressures
plotname = 'Droop Control, +100% Dist on P1';
number   = 9;
save('P0Workspace');
P0Plot();

% Simulate SP change for P, to see PI controller response
z1st   = 0;                                    % Pressure SP input
z2st   = 0;                                    % q2 SP input
z3st   = 0;                                    % q3 SP input
z4st   = 0;                                    % q4 SP input
z1dist = 0;                                    % Valve one input
z2dist = 0;                                    % Valve one input
z3dist = 0;                                    % Valve one input
z4dist = 0;                                    % Valve one input
P1dist = -P1*0.3;                              % Disturbance P1 input
P2dist = 0;                                    % Disturbance P2 input
P3dist = 0;                                    % Disturbance P3 input
P4dist = 0;                                    % Disturbance P4 input

sim('P0PressureFlowODESim')                    % Run Simulink file

qnomplot = t.^(0)*2.2;                         % Prepare plotting variables
q2plot   = q2stepplot;                         % Prepare plotting variables
q3plot   = q3stepplot;                         % Prepare plotting variables
q4plot   = q4stepplot;                         % Prepare plotting variables

save(fullfile(savdir,'P9910CL'));              % Save variables for later

% Plot pressures and and flows
%pressures
plotname = 'Droop Control, -30% Dist on P1';
number   = 10;
save('P0Workspace');
P0Plot();

% %% Save Figures as .png and eps
% savdir = '/Users/erikandrevik/Dropbox/MATLAB/Project2020/Erik2/88 Plots';
% saveas(figure(1),fullfile(savdir,'P8801CL'),'epsc');
% saveas(figure(1),fullfile(savdir,'P8801CL.png'));
% saveas(figure(2),fullfile(savdir,'P8802CL'),'epsc');
% saveas(figure(2),fullfile(savdir,'P8802CL.png'));
% saveas(figure(3),fullfile(savdir,'P8803CL'),'epsc');
% saveas(figure(3),fullfile(savdir,'P8803CL.png'));
% saveas(figure(4),fullfile(savdir,'P8804CL'),'epsc');
% saveas(figure(4),fullfile(savdir,'P8804CL.png'));
% saveas(figure(5),fullfile(savdir,'P8805CL'),'epsc');
% saveas(figure(5),fullfile(savdir,'P8805CL.png'));
% saveas(figure(6),fullfile(savdir,'P8806CL'),'epsc');
% saveas(figure(6),fullfile(savdir,'P8806CL.png'));
% saveas(figure(7),fullfile(savdir,'P8807CL'),'epsc');
% saveas(figure(7),fullfile(savdir,'P8807CL.png'));
% saveas(figure(8),fullfile(savdir,'P8808CL'),'epsc');
% saveas(figure(8),fullfile(savdir,'P8808CL.png'));
% saveas(figure(9),fullfile(savdir,'P8809CL'),'epsc');
% saveas(figure(9),fullfile(savdir,'P8809CL.png'));
% saveas(figure(10),fullfile(savdir,'P8810CL'),'epsc');
% saveas(figure(10),fullfile(savdir,'P8810CL.png'));

clc; 
clear;
close all

%% Plotting all results in same plots
Path = "/Users/erikandrevik/Dropbox/MATLAB/Project2020/Erik2/88 Data from Simulations";
addpath(Path);

ListOfPlots = ["P9901CL";
    "P9902CL";
    "P9903CL";
    "P9904CL";
    "P9905CL";
    "P9906CL";
    "P9907CL";
    "P9908CL";
    "P9909CL";
    "P9910CL"];

%% Plotting + 100% Disturbance from P1
for i = 3:2:length(ListOfPlots)
load(ListOfPlots(i))

pstepplot = t.^(0)*10;                        % Preparing plotting
qnomplot = t.^(0)*2.2;                         % Preparing plotting
q2plot   = t.^(0)*0.5;                         % Preparing plotting
q3plot   = t.^(0)*0.75;                        % Preparing plotting
q4plot   = t.^(0)*0.75;                        % Preparing plotting

figure(11)
y = sgtitle('Closed Loop Response, -30% Disturbance from P1');
y.FontWeight = 'bold';
subplot(5,2,1)
plot(t, u(:,1))
hold on
xlabel('Time [s]')
ylabel('Opening z_1 [-]')
xlim([0 tsim])
ylim([0 1])

subplot(5,2,2)
plot(t,P(:,1)) 
hold on
xlabel('Time [s]')
ylabel('P [bar]')
xlim([0 tsim])
ylim([8 12])

subplot(5,2,3)
plot(t, u(:,2))
hold on
xlabel('Time [s]')
ylabel('Opening z_2 [-]')
xlim([0 tsim])
ylim([0 1])

subplot(5,2,4)
plot(t,q(:,2))
hold on
xlabel('Time [s]')
ylabel('q_2 [kmol/s]')
xlim([0 tsim])
ylim([0 1.5])

subplot(5,2,5)
plot(t, u(:,3))
hold on
xlabel('Time [s]')
ylabel('Opening z_3 [-]')
xlim([0 tsim])
ylim([0 1])

subplot(5,2,6)
plot(t,q(:,3))
hold on
xlabel('Time [s]')
ylabel('q_3 [kmol/s]')
xlim([0 tsim])
ylim([0 1.5])

subplot(5,2,7)
plot(t, u(:,4))
hold on
xlabel('Time [s]')
ylabel('Opening z_4 [-]')
xlim([0 tsim])
ylim([0 1])

subplot(5,2,8)
plot(t,q(:,4))
hold on
xlabel('Time [s]')
ylabel('q_4 [kmol/s]')
xlim([0 tsim])
ylim([0 1.5])

subplot(5,2,10)
plot(t,q(:,1))
hold on
xlabel('Time [s]')
ylabel('q [kmol/s]')
xlim([0 tsim])
ylim([0 2.2])
end

figure(11)
subplot(5,2,2)
plot(t,pstepplot,'-.b')
hold on

subplot(5,2,4)
plot(t,q2plot,'-.b')
hold on

subplot(5,2,6)
plot(t,q3plot,'-.b')
hold on

subplot(5,2,8)
plot(t,q4plot,'-.b')
hold on

subplot(5,2,10)
plot(t,qnomplot,'-.b')
hold on

subplot(5,2,9)
plot(0,0, 0,0, 0,0, 0,0, 0,0, '-.b')
axis off
legend('1: Default Control',...
    '2: Parallel control Using Equal Setpoints', ...
    '3: Parallel Control Using Different Setpoints',...
    '4: Droop Control',...
    'Nominal Value q_2-q_4/Maximum Value q',...
    'location','southwest')

%% Plotting -30% Disturbance from P1
for i = 4:2:length(ListOfPlots)
load(ListOfPlots(i))

pstepplot = t.^(0)*10;                        % Preparing plotting
qnomplot = t.^(0)*2.2;                         % Preparing plotting
q2plot   = t.^(0)*0.5;                         % Preparing plotting
q3plot   = t.^(0)*0.75;                        % Preparing plotting
q4plot   = t.^(0)*0.75;                        % Preparing plotting

figure(12)
y = sgtitle('Closed Loop Response, -30% Disturbance from P1');
y.FontWeight = 'bold';
subplot(5,2,1)
plot(t, u(:,1))
hold on
xlabel('Time [s]')
ylabel('Opening z_1 [-]')
xlim([0 tsim])
ylim([0 1])

subplot(5,2,2)
plot(t,P(:,1)) 
hold on
xlabel('Time [s]')
ylabel('P [bar]')
xlim([0 tsim])
ylim([8 12])

subplot(5,2,3)
plot(t, u(:,2))
hold on
xlabel('Time [s]')
ylabel('Opening z_2 [-]')
xlim([0 tsim])
ylim([0 1])

subplot(5,2,4)
plot(t,q(:,2))
hold on
xlabel('Time [s]')
ylabel('q_2 [kmol/s]')
xlim([0 tsim])
ylim([0 1.5])

subplot(5,2,5)
plot(t, u(:,3))
hold on
xlabel('Time [s]')
ylabel('Opening z_3 [-]')
xlim([0 tsim])
ylim([0 1])

subplot(5,2,6)
plot(t,q(:,3))
hold on
xlabel('Time [s]')
ylabel('q_3 [kmol/s]')
xlim([0 tsim])
ylim([0 1.5])

subplot(5,2,7)
plot(t, u(:,4))
hold on
xlabel('Time [s]')
ylabel('Opening z_4 [-]')
xlim([0 tsim])
ylim([0 1])

subplot(5,2,8)
plot(t,q(:,4))
hold on
xlabel('Time [s]')
ylabel('q_4 [kmol/s]')
xlim([0 tsim])
ylim([0 1.5])

subplot(5,2,10)
plot(t,q(:,1))
hold on
xlabel('Time [s]')
ylabel('q [kmol/s]')
xlim([0 tsim])
ylim([0 2.2])
end

figure(12)
subplot(5,2,2)
plot(t,pstepplot,'-.b')
hold on

subplot(5,2,4)
plot(t,q2plot,'-.b')
hold on

subplot(5,2,6)
plot(t,q3plot,'-.b')
hold on

subplot(5,2,8)
plot(t,q4plot,'-.b')
hold on

subplot(5,2,10)
plot(t,qnomplot,'-.b')
hold on

subplot(5,2,9)
plot(0,0, 0,0, 0,0, 0,0, 0,0, '-.b')
axis off
legend('1: Default Control',...
    '2: Parallel control Using Equal Setpoints', ...
    '3: Parallel Control Using Different Setpoints',...
    '4: Droop Control',...
    'Nominal Value q_2-q_4/Maximum Value q',...
    'location','southwest')

